pub struct SemanticObject<ObjectCategory> { /* private fields */ }Expand description
Represents a distinct semantically annotated object.
The source index is also the object’s semantic id.
Implementations
Sourceimpl<ObjectCategory> SemanticObject<ObjectCategory>
impl<ObjectCategory> SemanticObject<ObjectCategory>
Sourcepub const fn new(index: i32, category: Option<ObjectCategory>, obb: Obb) -> Self
pub const fn new(index: i32, category: Option<ObjectCategory>, obb: Obb) -> Self
Creates a semantic object.
index is the original descriptor index for this object.
Sourcepub const fn semantic_id(&self) -> i32
pub const fn semantic_id(&self) -> i32
Returns the unique semantic id corresponding to this object.
Sourcepub const fn category(&self) -> Option<&ObjectCategory>
pub const fn category(&self) -> Option<&ObjectCategory>
Returns this object’s dataset-specific category.