semantic-scene
Rust parser for semantic scene descriptors. Currently supports Habitat-Sim/Matterport3D .house files from the MP3D dataset.
💡 Examples
The primary API is dataset-first and Rust-native.
For example, to load a .house file:
use semantic_scene::{Mp3d, Mp3dOptions, SemanticScene};
let scene =
SemanticScene::load::<Mp3d>("data/17DRP5sb8fy.house", Mp3dOptions::default()).unwrap();
println!("{scene:#}");📥 Installation
The
semantic-sceneCLI tool takes a path to a.housefile and displays a human-readable summary of the scene.
Using binstall
cargo binstall semantic-sceneDownloading from Releases
Navigate to the Releases page and download respective binary for your platform. Make sure to give it execute permissions.
Compiling from Source
cargo install semantic-scene✅ TODO
-
Enum-based category (
Mp3dObjectCategory,Mp3dRegionCategory)
🎉 Credits
TODO
Re-exports
pub use dataset::Dataset;pub use error::LoadError;pub use error::ParseError;pub use math::Aabb;pub use math::Obb;pub use math::Rotation3;pub use math::Vec2;pub use math::Vec3;pub use mp3d::Mp3d;pub use mp3d::Mp3dCategoryMapping;pub use mp3d::Mp3dObjectCategory;pub use mp3d::Mp3dOptions;pub use mp3d::Mp3dRegionCategory;
Modules
- dataset
- Generic dataset loading traits.
- error
- Error types returned by parsers and loaders.
- math
- Geometry primitives used by
SemanticScene. - mp3d
- MP3D dataset support.
Structs
- Semantic
Level - Represents a level of a semantic scene.
- Semantic
Object - Represents a distinct semantically annotated object.
- Semantic
Region - Represents a semantic region, typically a room in a level of a house.
- Semantic
Scene - Scene containing semantically annotated levels, regions, and objects.