pub struct SemanticObject { /* private fields */ }Expand description
Represents a distinct semantically annotated object.
The source index is also the object’s semantic id, matching Habitat-Sim’s
SemanticObject::semanticID().
Implementations
Sourceimpl SemanticObject
impl SemanticObject
Sourcepub fn id(&self, scene: &SemanticScene) -> String
pub fn id(&self, scene: &SemanticScene) -> String
Returns the Habitat-Sim-style object id.
If the object has a parent region, the form is
<level_id>_<region_id>_<object_id>. Otherwise, the form is
_<object_id>.
Sourcepub const fn semantic_id(&self) -> i32
pub const fn semantic_id(&self) -> i32
Returns the unique semantic id corresponding to this object.
Sourcepub const fn region_index(&self) -> Option<usize>
pub const fn region_index(&self) -> Option<usize>
Returns the index of this object’s parent region in SemanticScene::regions.
Sourcepub const fn category_index(&self) -> Option<usize>
pub const fn category_index(&self) -> Option<usize>
Returns the index of this object’s category in SemanticScene::categories.