SemanticObject

Struct SemanticObject 

pub struct SemanticObject<ObjectCategory> { /* private fields */ }
Represents a distinct semantically annotated object.

The source index is also the object’s semantic id.

Implementations

Source

impl<ObjectCategory> SemanticObject<ObjectCategory>

pub const fn new(index: i32, category: Option<ObjectCategory>, obb: Obb) -> Self

Creates a semantic object.

index is the original descriptor index for this object.

pub const fn index(&self) -> i32

Returns the original descriptor index.

pub const fn semantic_id(&self) -> i32

Returns the unique semantic id corresponding to this object.

pub const fn category(&self) -> Option<&ObjectCategory>

Returns this object’s dataset-specific category.

pub fn aabb(&self) -> Aabb

Returns the axis-aligned bounding box enclosing this object.

pub const fn obb(&self) -> &Obb

Returns the object’s oriented bounding box.